@@ -1,4 +1,4 @@
-VERSION = (1, 1, 2, 'final', 0)
+VERSION = (2, 0, 2, "final", 0)
 
 
 def get_version(version=None):
@@ -6,7 +6,7 @@ def get_version(version=None):
     if version is None:
         version = VERSION
     assert len(version) == 5
-    assert version[3] in ('alpha', 'beta', 'rc', 'final')
+    assert version[3] in ("alpha", "beta", "rc", "final")
 
     # Now build the two parts of the version number:
     # main = X.Y[.Z]
@@ -14,11 +14,11 @@ def get_version(version=None):
     #     | {a|b|c}N - for alpha, beta and rc releases
 
     parts = 2 if version[2] == 0 else 3
-    main = '.'.join(str(x) for x in version[:parts])
+    main = ".".join(str(x) for x in version[:parts])
 
-    sub = ''
-    if version[3] != 'final':
-        mapping = {'alpha': 'a', 'beta': 'b', 'rc': 'c'}
+    sub = ""
+    if version[3] != "final":  # pragma: no cover
+        mapping = {"alpha": "a", "beta": "b", "rc": "c"}
         sub = mapping[version[3]] + str(version[4])
 
     return main + sub
